@@ -839,9 +839,6 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
